import { 
  select, 
  csv, 
  scaleLinear, 
  max,
  axisLeft,
  axisBottom,
  extent,
  format,
  timeParse,
  timeFormat
} from 'd3';

export const scatterPoints = (selection, props) => {
  const {data,
         xValue,
         yValue,
         circleRadius,
         margin,
         title,
         xAxisLabel,
         yAxisLabel,
         innerWidth,
         innerHeight,
         formatDate} = props;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const xAxisTickFormat = data =>
    formatDate(data);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20)
    .tickFormat(xAxisTickFormat);
   
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0,innerHeight])
    .nice();
  
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(20);
  
  
  const g = selection.append('g')
    .attr('transform', `translate(${margin.left},${margin.right})`);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
   
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerHeight})`)
    .selectAll("text")
      .style("text-anchor", "end")
        .attr("dx", "-.8em")
        .attr("dy", ".15em")
        .attr("transform", "rotate(-65)");
  
  xAxisG.select('.domain').remove();
  
  g.append('text')
    .attr('class', 'title')
    .attr('y', -3)
    .attr('fill', 'black')
    .text(title);

  xAxisG.append('text')
    .attr('class','axis-label')
    .attr('y', 55)
    .attr('x', innerWidth / 2)
    .attr('fill', 'black')
    .text(xAxisLabel);
  
  yAxisG.append('text')
    .attr('class','axis-label')
    .attr('y', -80)
    .attr('x', -innerHeight / 2)
    .attr('transform',`rotate(-90)`)
    .attr('fill', 'black')
    .attr('text-anchor', 'middle')
    .text(yAxisLabel);
  
 
  g.selectAll('circle')
    .data(data)
  	  .enter()
        .append('circle')
  		.attr('cy', d => yScale(yValue(d)))
        .attr('cx', d => xScale(xValue(d)))
        .attr('r', circleRadius);
}
